"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const StringBuilder_1 = require("../StringBuilder");
const LoggingProperty_1 = require("./LoggingProperty");
const LogLevel_1 = require("./LogLevel");
class Logger {
    verbose;
    properties;
    currentIndent;
    constructor(verbose, properties, currentIndent = 0) {
        this.verbose = verbose;
        this.properties = properties;
        this.currentIndent = currentIndent;
    }
    static start(verbose, functionName, details, logLevel = 'debug') {
        const property = new LoggingProperty_1.LoggingProperty(functionName, new LogLevel_1.LogLevel(logLevel), 0, details);
        return new Logger(verbose, [property]);
    }
    get nextIndent() {
        return new Logger(this.verbose, this.properties, this.currentIndent + 1);
    }
    log(functionName, details, logLevel = 'debug') {
        this.properties.push(new LoggingProperty_1.LoggingProperty(functionName, new LogLevel_1.LogLevel(logLevel), this.currentIndent, details));
    }
    get completeLog() {
        const builder = new StringBuilder_1.StringBuilder();
        for (const property of this.properties)
            builder.append(property.completeLog(this.verbose));
        return builder.toString();
    }
}
exports.Logger = Logger;
